@@ -288,7 +288,7 @@ class SSSave:
             
         else:
             
-            self.filename, self.directlink, self.valid = self.__file_exists(filename), directlink, True
+            self.filename, self.directlink, self.valid = filename, directlink, True
             
     def __file_exists(self, filename):
         
@@ -318,18 +318,24 @@ class SSSave:
             
             return filename
     
-    def __show_progress(self, current, total):
+    def __show_progress(self, current, total, endline = False):
         
         if (self.progress_bar):
         
-            sys.stdout.write(f"\rDownloading [{self.directlink}] -> [{self.filename}] ({current/total*100}%)")
+            sys.stdout.write(f"\rDownloading [{self.directlink}] -> [{self.filename}] ({round(current/total*100, 1)}%)")
             
             sys.stdout.flush()
+
+        if (endline):
+   
+            print("\n")
     
     def download(self):
         
         if (self.valid):
-            
+
+            self.filename = self.__file_exists(self.filename)
+
             fileData = requests.get(self.directlink, stream = True)
             
             length = int(fileData.headers.get("content-length"))
@@ -348,7 +354,7 @@ class SSSave:
                     
                     temp += len(data)
                     
-            self.__show_progress(temp, length)
+            self.__show_progress(temp, length, endline = True)
         
         else:
             
